# Generated by Django 4.2 on 2023-12-02 03:20

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('advance', '0006_delete_javascript'),
    ]

    operations = [
        migrations.CreateModel(
            name='admin_update',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=100)),
                ('url', models.URLField(default='bigsansar.com/dashboard')),
                ('publish_date', models.DateField(auto_now_add=True)),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'verbose_name': 'update',
                'verbose_name_plural': 'Admin Update',
            },
        ),
    ]
