{% extends 'base.html' %}
{%block title %} bigsansar - login {% endblock %}
{% block head %}
{% load static %}
<link rel="stylesheet" href="{% static 'style.css' %}">
{% endblock %}
{% block body %}
{% include 'admin/nav.html' %}


<!-- for description-->

{% if messages %}
       {% for message in messages %}
      {% if message.tags %}
              <div class="alert alert-{{ message.tags }} alert-dismissible fade show" role="alert">
          {{ message }}
          <button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close">
          </button>
        </div>
      {% endif %}
      {% endfor %}
      {% endif %}


<div class="wrapper">
    <form class="form" method="post" action="" >
        <h2 class="form-heading text-center">Login</h2><br/>
        {% csrf_token %}
        {{form.as_p}}
        <p class="text-center"><a href="/lostpass">Forget Password?</a></p>
        <p class="text-center"><button type="submit" class="btn btn-lg btn-primary btn-block">Login</button>
        <a class="btn btn-lg btn-dark btn-block" href="/signup" role="button">Sign Up</a></p>

    </form>
</div>
{% endblock %}