from django.apps import AppConfig


class AdvanceConfig(AppConfig):
    default_auto_field = 'django.db.models.BigAutoField'
    name = 'bigsansar.contrib.advance'
    verbose_name = 'Advance Function'
