# Generated by Django 4.2 on 2023-06-25 11:55

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('advance', '0005_delete_css'),
    ]

    operations = [
        migrations.DeleteModel(
            name='javascript',
        ),
    ]
